__marqo_version__ = "1.3.0"
__marqo_release_page__ = f"https://github.com/marqo-ai/marqo/releases/tag/{__marqo_version__}"

__minimum_supported_marqo_version__ = "1.0.0"


def supported_marqo_version() -> str:
    return f"This Marqo Python client is built for Marqo release ({__marqo_version__}) \n" \
           f"{__marqo_release_page__} \n" \
           f"The minimum supported Marqo version for this client is ({__minimum_supported_marqo_version__}) \n"


def minimum_supported_marqo_version() -> str:
    return __minimum_supported_marqo_version__



from typing import Optional

from marqo.instance_mappings import InstanceMappings


class Config:
    """
    Client's credentials and configuration parameters
    """

    def __init__(
            self,
            instance_mappings: Optional[InstanceMappings] = None,
            is_marqo_cloud: bool = False,
            use_telemetry: bool = False,
            timeout: Optional[int] = None,
            api_key: str = None
    ) -> None:
        """
        Parameters
        ----------
        url:
            The url to the Marqo instance (ex: http://localhost:8882)
        """
        self.instance_mapping = instance_mappings
        self.is_marqo_cloud = is_marqo_cloud
        self.use_telemetry = use_telemetry
        self.timeout = timeout
        self.api_key = api_key
        # suppress warnings until we figure out the dependency issues:
        # warnings.filterwarnings("ignore")
